@@ -3,6 +3,7 @@
 
 # import aiohttp
 # import asyncio
+import base64
 import requests
 
 # declare global variables
@@ -63,12 +64,14 @@ def get_knowledge_bases():
         knowledge_bases[knowledge_base['id']] = kb
 
 
-def init(api_key: str, verbose: bool = False):
+def init(api_key_id: str, api_key_secret: str, verbose: bool = False):
     global HEADERS
     global models
     global incantations
     global knowledge_bases
-    HEADERS = {'x-api-key': api_key}
+
+    token = base64.b64encode((f'{api_key_id}:{api_key_secret}').encode('utf-8')).decode('utf-8')
+    HEADERS = {'Authorization': f'Bearer {token}'}
 
     # get the current state with models and incantations
     get_models()
@@ -221,6 +224,20 @@ class Model:
         resp_body = instance_obj.create()
         return instance_obj
 
+    # convenience method for non-conversational use case - TODO: this is not an efficient way to do this
+    def run(self, prompt: str) -> str:
+        # create a new instance
+        instance_obj = self.create_instance()
+        instance_id = instance_obj.instance_id
+
+        # get the response
+        url = BASE_URL + f'models/{self.model_id}/instances/{instance_id}/get_response'
+        human_input = [{"prefix": "", "content": prompt}]
+        payload = {
+            'human_input': human_input
+        }
+        resp = _format_http_response(requests.post(url, headers=HEADERS, json=payload))
+        return resp['body']['model_response']['content']
 
 class ModelInstance:
     def __init__(self, ai_name: str, knowledge_bases: list = None, model_id: str = None, supp_id: str = None, description: str = None, instance_id = None):
@@ -397,12 +414,13 @@ def update_incantation(incantation_title: str, new_text: str = None, new_title:
     return incantation_obj
 
 # create_model() is a convenience function that creates a Model object and then calls its create() method
-def create_model(model_spec: dict, verbose: bool = False):
-    #if model_spec["model_title"] in models:
-    #    return get_model(model_spec["model_title"])
-
+def create_model(model_spec: dict = {}, verbose: bool = False):
+    if model_spec == {}:
+        model_spec = {
+            "incantation_names": [],
+            "title": "Untitled model",
+        }
     model_spec = model_spec_preprocessing(model_spec)
-    
     if verbose: print ("Model spec:\n", model_spec)
     model_obj = Model(model_spec=model_spec)
     body_resp = model_obj.create()
